# Fraim Documentation

Welcome to Fraim - a flexible framework designed for security teams to build and deploy AI-powered workflows that complement their existing security operations.

## What is Fraim?

Fraim empowers security teams to easily create, customize, and deploy AI workflows tailored to their specific security needs. Rather than providing a one-size-fits-all solution, Fraim gives teams the building blocks to construct intelligent automation that integrates seamlessly with their existing security stack.

## Key Features

### 🚀 Framework-First Approach
Build custom AI workflows instead of using rigid, pre-built tools. Fraim provides the foundation, you create the solutions that fit your exact needs.

### 🔒 Security Team Focused
Designed specifically for security operations and threat analysis, with workflows that understand the unique challenges of security teams.

### 🔧 Extensible Architecture
Easily add new workflows, data sources, and AI models. The modular design allows for seamless integration with your existing toolchain.

### 🤖 Multi-LLM Support
Works with multiple AI providers including:
- Google Gemini
- OpenAI GPT models
- Anthropic
- Other [LiteLLM-supported providers](https://docs.litellm.ai/docs/providers)

## Core Architecture

Fraim is built with modularity and extensibility in mind:

### Key Components

- **🔄 Workflow Engine**: Orchestrates AI agents and security analysis tools
- **🧠 LLM Integrations**: Support for multiple AI providers with unified interface
- **🛠️ Tool System**: Extensible security analysis tools ready for use by LLMs
- **🪛 Templated Prompts**: Customize your prompts using Jinja templates
- **📥 Input Connectors**: Use your repo locally or remote as an input into the LLM
- **📊 Output Formatters**: SARIF and HTML report generation
- **👁️ Observability**: Monitoring and tracking with Langfuse integration

## Getting Started

Ready to start using Fraim? Check out our detailed guides:

- [Installation](installation.md) - Step-by-step installation instructions
- [CLI Usage Guide](cli-usage.md) - Complete guide to using the Fraim command-line interface
- [Workflows](workflows/workflows.md) - Understanding and creating custom workflows

## Use Cases

Fraim is perfect for:

- **Security Code Reviews**: Automated analysis of code changes and pull requests
- **CI/CD Integration**: Continuous security scanning in your development pipeline
- **Compliance Auditing**: Regular security assessments for compliance requirements
- **Threat Hunting**: Custom workflows for identifying specific security patterns
- **Security Training**: Educational tool for understanding common vulnerabilities

## Community & Support

- **GitHub Issues**: Report bugs and request features
- **Discussions**: Join the community for questions and ideas
- **Contributing**: Help improve Fraim by contributing code, workflows, or documentation

---

*Built by security teams, for security teams. Making AI-powered security accessible to everyone.* 